@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta project, made within the KDE community.
 
-    SPDX-FileCopyrightText: 2009, 2011, 2015 Friedrich W. H. Kossebau <kossebau@kde.org>
+    Copyright 2009,2011 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     Public domain.
 */
@@ -11,15 +11,20 @@
 #include "ui_example_widget.h"
 //// include the header of the bytearray model you want to use
 // Okteta core
-#include <Okteta/PieceTableByteArrayModel>
+#include <okteta1/piecetablebytearraymodel.h>
+//// or
+#include <Okteta1/PieceTableByteArrayModel>
 
 //// only needed for the example
-// Qt
-#include <QApplication>
+// KDE
+#include <KApplication>
+#include <KCmdLineArgs>
+#include <KAboutData>
+
 
 //// some static data so the bytearray model is not empty on start
 //// and the widgets not just white after the start of the example program :)
-static constexpr char exampleInitialData[] =
+static const char exampleInitialData[] =
     "This is some data for the Okteta byte array widgets:"
     "\x00\x01\x02\x03\x04\x05\x06\x07\x08\x09\x0A\x0B\x0C\x0D\x0E\x0F"
     "\x10\x11\x12\x13\x14\x15\x16\x17\x18\x19\x1A\x1B\x1C\x1D\x1E\x1F"
@@ -38,15 +43,16 @@ static constexpr char exampleInitialData[] =
     "\xE0\xE1\xE2\xE3\xE4\xE5\xE6\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF"
     "\xF0\xF1\xF2\xF3\xF4\xF5\xF6\xF7\xF8\xF9\xFA\xFB\xFC\xFD\xFE\xFF";
 
-static constexpr std::size_t exampleInitialDataSize = sizeof(exampleInitialData) / sizeof(exampleInitialData[0]);
+static const int exampleInitialDataSize = sizeof(exampleInitialData) / sizeof(exampleInitialData[0]);
+
 
 class Widget : public QWidget
 {
-public:
-    explicit Widget(QWidget* parent = nullptr);
-    ~Widget() override;
+  public:
+    explicit Widget( QWidget* parent = 0 );
+    virtual ~Widget();
 
-private:
+  private:
     Ui::Example_Widget ui;
 
     //// the bytearray, by a class subclassing Okteta::AbstractByteArrayModel,
@@ -55,31 +61,35 @@ private:
     Okteta::PieceTableByteArrayModel* mByteArrayModel;
 };
 
-Widget::Widget(QWidget* parent)
-    : QWidget(parent)
+
+Widget::Widget( QWidget* parent )
+  : QWidget(parent)
 {
     //// initialize as usual when using UI files
-    ui.setupUi(this);
+    ui.setupUi( this );
 
     //// create the bytearray
     mByteArrayModel =
-        new Okteta::PieceTableByteArrayModel(QByteArray::fromRawData(exampleInitialData, exampleInitialDataSize), this);
+        new Okteta::PieceTableByteArrayModel( QByteArray::fromRawData(exampleInitialData,exampleInitialDataSize), this );
 
     //// then set it to the bytearray view
     //// the same bytearray object can be set to multiple views
     //// they will share it, as the Okteta classes implement the MVC pattern
-    ui.mByteArrayColumnView->setByteArrayModel(mByteArrayModel);
-    ui.mByteArrayRowView->setByteArrayModel(mByteArrayModel);
+    ui.mByteArrayColumnView->setByteArrayModel( mByteArrayModel );
+    ui.mByteArrayRowView->setByteArrayModel( mByteArrayModel );
 }
 
-Widget::~Widget() = default;
+Widget::~Widget() {}
 
-int main(int argc, char* argv[])
+
+int main( int argc, char* argv[] )
 {
-    QApplication programCore(argc, argv);
+    KAboutData aboutData( "uitest", "UIT", ki18n(""), "", ki18n("") );
+    KCmdLineArgs::init( argc, argv, &aboutData );
+    KApplication programCore;
 
-    auto* widget = new Widget;
+    Widget* widget = new Widget;
     widget->show();
 
-    return QApplication::exec();
+    return programCore.exec();
 }
